@@ -6,7 +6,7 @@ from urllib import parse
 session=requests.session()
 def login(username,password):
     headers = {"Content-Type": "application/x-www-form-urlencoded"}
-    API='http://daas.smartsteps.com/qsqltest/certificateauth/authen/login'
+    API='http://daas.smartsteps.com/certificateauth/authen/login'
     data={
            "userName":username,
             "password":password
